/**
 * Proxy server configuration.
 */
declare class ProxyConfiguration {
    /**
     * Proxy type.
     */
    readonly type: ProxyType;
    /**
     * Proxy address. Can be either in the IP address format, ex. "1.1.1.1", or hostname, ex. "example.com".
     */
    readonly address: string;
    /**
     * Proxy port.
     */
    readonly port: number;
    /**
     * Username for Basic authentication scheme.
     *
     * Note: "SOCKS + authentication" scheme is not supported.
     */
    readonly username?: string | undefined;
    /**
     * Password for Basic authentication scheme.
     */
    readonly password?: string | undefined;
    constructor(
    /**
     * Proxy type.
     */
    type: ProxyType, 
    /**
     * Proxy address. Can be either in the IP address format, ex. "1.1.1.1", or hostname, ex. "example.com".
     */
    address: string, 
    /**
     * Proxy port.
     */
    port: number, 
    /**
     * Username for Basic authentication scheme.
     *
     * Note: "SOCKS + authentication" scheme is not supported.
     */
    username?: string | undefined, 
    /**
     * Password for Basic authentication scheme.
     */
    password?: string | undefined);
}
declare enum ProxyType {
    HTTP = "http",
    HTTPS = "https",
    SOCKS = "socks"
}
export { ProxyConfiguration, ProxyType };
